"""DSM 7 SYNO.Virtualization.Guest data."""

DSM_7_VMM_GUESTS = {
    "data": {
        "canHA": False,
        "canMove": True,
        "guests": [
            {
                "autorun": 0,
                "birth_info": {"desc": "", "from": "vmm", "method": "create"},
                "boot_from": "disk",
                "can_ha": True,
                "cpu_passthru": True,
                "cpu_pin_num": 0,
                "cpu_weight": 8,
                "desc": "vDSM test",
                "dsm_version": "DSM 7.2.1-69057 Update 5",
                "guest_id": "a39d0628-380e-42f8-8cb6-a00d6b930fa0",
                "ha_status": "",
                "ha_status_detail": "",
                "ha_status_type": "",
                "host_id": "f0310cdf-fa88-47d3-9e9e-be36fb8e121b",
                "host_name": "KrosseKrabbe",
                "host_ram_size": 6291456,
                "http_port": 5000,
                "https_enable": False,
                "https_port": 5001,
                "https_redirect": False,
                "hyperv_enlighten": False,
                "ip": "",
                "is_acting": False,
                "is_general_vm": False,
                "is_online": False,
                "is_replica_support": True,
                "is_rs_install": True,
                "iso_images": ["unmounted", "unmounted"],
                "kb_layout": "Default",
                "name": "vdsm",
                "ram_used": 0,
                "repo_id": "3a69ac31-004c-4b02-9b36-609099bc9be6",
                "repo_name": "KrosseKrabbe - VM Storage 1",
                "snap_num": 0,
                "status": "shutdown",
                "status_desc": "",
                "status_type": "healthy",
                "usb_device_name": None,
                "usbs": ["unmounted", "unmounted", "unmounted", "unmounted"],
                "use_ovmf": False,
                "vcpu_num": 1,
                "vcpu_usage": "",
                "vdisk_num": 3,
                "video_card": "cirrus",
                "vram_size": 1048576,
            },
            {
                "autorun": 1,
                "birth_info": {"desc": "", "from": "vmm", "method": "create"},
                "boot_from": "disk",
                "can_ha": True,
                "cpu_passthru": True,
                "cpu_pin_num": 0,
                "cpu_weight": 256,
                "desc": "",
                "dsm_version": "",
                "guest_id": "2b4ec8c8-2bec-4daa-b36d-1a47b639254f",
                "ha_status": "",
                "ha_status_detail": "",
                "ha_status_type": "",
                "has_agent": False,
                "host_id": "f0310cdf-fa88-47d3-9e9e-be36fb8e121b",
                "host_name": "KrosseKrabbe",
                "host_net_ifs": ["f0310cdf-fa88-47d3-9e9e-be36fb8e121b_bond0"],
                "host_ram_size": 6291456,
                "http_port": 5000,
                "https_enable": False,
                "https_port": 5001,
                "https_redirect": False,
                "hyperv_enlighten": True,
                "ip": "",
                "is_acting": False,
                "is_general_vm": True,
                "is_online": True,
                "is_replica_support": True,
                "is_rs_install": True,
                "iso_images": ["unmounted", "unmounted"],
                "kb_layout": "Default",
                "max_disk_latency": 0,
                "name": "lnx_test",
                "ram_used": 1169544,
                "repo_id": "3a69ac31-004c-4b02-9b36-609099bc9be6",
                "repo_name": "KrosseKrabbe - VM Storage 1",
                "snap_num": 0,
                "status": "running",
                "status_desc": "",
                "status_type": "healthy",
                "total_disk_iops": 0,
                "total_disk_throughput": 0,
                "total_net_receive": 0,
                "total_net_send": 0,
                "usb_device_name": None,
                "usbs": ["unmounted", "unmounted", "unmounted", "unmounted"],
                "use_ovmf": False,
                "vcpu_num": 1,
                "vcpu_usage": 25,
                "vdisk_num": 1,
                "video_card": "vmvga",
                "vram_size": 1048576,
            },
        ],
        "is_freeze": False,
    },
    "success": True,
}
