"""DSM 6 SYNO.Core.Share data."""

DSM_6_CORE_SHARE = {
    "data": {
        "shares": [
            {
                "desc": "Docker Containers",
                "enable_recycle_bin": False,
                "enable_share_compress": False,
                "enable_share_cow": True,
                "enc_auto_mount": False,
                "encryption": 0,
                "force_readonly_reason": "",
                "hidden": True,
                "is_aclmode": True,
                "is_block_snap_action": False,
                "is_cluster_share": False,
                "is_cold_storage_share": False,
                "is_exfat_share": False,
                "is_force_readonly": False,
                "is_share_moving": False,
                "is_support_acl": True,
                "is_sync_share": False,
                "is_usb_share": False,
                "name": "docker",
                "quota_value": 0,
                "recycle_bin_admin_only": False,
                "share_quota_used": 0,
                "support_action": 511,
                "support_snapshot": True,
                "task_id": "",
                "unite_permission": False,
                "uuid": "78egut02-b5b1-4933-adt8-a9208526d234",
                "vol_path": "/volume1",
            },
            {
                "desc": "",
                "enable_recycle_bin": True,
                "enable_share_compress": False,
                "enable_share_cow": True,
                "enc_auto_mount": False,
                "encryption": 0,
                "force_readonly_reason": "",
                "hidden": False,
                "is_aclmode": True,
                "is_block_snap_action": False,
                "is_cluster_share": False,
                "is_cold_storage_share": False,
                "is_exfat_share": False,
                "is_force_readonly": False,
                "is_share_moving": False,
                "is_support_acl": True,
                "is_sync_share": False,
                "is_usb_share": False,
                "name": "test_share",
                "quota_value": 0,
                "recycle_bin_admin_only": False,
                "share_quota_used": 36146658672640.0,
                "support_action": 511,
                "support_snapshot": True,
                "task_id": "",
                "unite_permission": False,
                "uuid": "2ee6c06a-8766-48b5-013d-63b18652a393",
                "vol_path": "/volume1",
            },
            {
                "desc": "user home",
                "enable_recycle_bin": False,
                "enable_share_compress": False,
                "enable_share_cow": True,
                "enc_auto_mount": False,
                "encryption": 0,
                "force_readonly_reason": "",
                "hidden": False,
                "is_aclmode": True,
                "is_block_snap_action": False,
                "is_cluster_share": False,
                "is_cold_storage_share": False,
                "is_exfat_share": False,
                "is_force_readonly": False,
                "is_share_moving": False,
                "is_support_acl": True,
                "is_sync_share": False,
                "is_usb_share": False,
                "name": "homes",
                "quota_value": 0,
                "recycle_bin_admin_only": False,
                "share_quota_used": 0.015625,
                "support_action": 511,
                "support_snapshot": True,
                "task_id": "",
                "unite_permission": False,
                "uuid": "2b829t90-9512-4236-qqe0-d4133e9992d0",
                "vol_path": "/volume1",
            },
            {
                "desc": "Log volume",
                "enable_recycle_bin": True,
                "enable_share_compress": True,
                "enable_share_cow": True,
                "enc_auto_mount": True,
                "encryption": 0,
                "force_readonly_reason": "",
                "hidden": True,
                "is_aclmode": True,
                "is_block_snap_action": False,
                "is_cluster_share": False,
                "is_cold_storage_share": False,
                "is_exfat_share": False,
                "is_force_readonly": False,
                "is_share_moving": False,
                "is_support_acl": True,
                "is_sync_share": False,
                "is_usb_share": False,
                "name": "logs",
                "quota_value": 0,
                "recycle_bin_admin_only": True,
                "share_quota_used": 947.28515625,
                "support_action": 511,
                "support_snapshot": True,
                "task_id": "",
                "unite_permission": False,
                "uuid": "b9876507-6880-4wes-8d61-6c984c0813ty",
                "vol_path": "/volume2",
            },
            {
                "desc": "VMs",
                "enable_recycle_bin": False,
                "enable_share_compress": False,
                "enable_share_cow": True,
                "enc_auto_mount": False,
                "encryption": 0,
                "force_readonly_reason": "",
                "hidden": False,
                "is_aclmode": True,
                "is_block_snap_action": False,
                "is_cluster_share": False,
                "is_cold_storage_share": False,
                "is_exfat_share": False,
                "is_force_readonly": False,
                "is_share_moving": False,
                "is_support_acl": True,
                "is_sync_share": False,
                "is_usb_share": False,
                "name": "Virtual_Machines",
                "quota_value": 0,
                "recycle_bin_admin_only": False,
                "share_quota_used": 33911668,
                "support_action": 511,
                "support_snapshot": True,
                "task_id": "",
                "unite_permission": False,
                "uuid": "5416f693-04tt-4re2-b8e4-f6b18731689b",
                "vol_path": "/volume3",
            },
        ],
        "total": 5,
    },
    "success": True,
}
