"""DSM 6 SYNO.Core.SecurityScan.Status data."""

DSM_6_CORE_SECURITY = {
    "data": {
        "items": {
            "malware": {
                "category": "malware",
                "fail": {
                    "danger": 0,
                    "info": 0,
                    "outOfDate": 0,
                    "risk": 0,
                    "warning": 0,
                },
                "failSeverity": "safe",
                "progress": 100,
                "runningItem": "",
                "total": 3,
                "waitNum": 0,
            },
            "network": {
                "category": "network",
                "fail": {
                    "danger": 0,
                    "info": 0,
                    "outOfDate": 0,
                    "risk": 0,
                    "warning": 0,
                },
                "failSeverity": "safe",
                "progress": 100,
                "runningItem": "",
                "total": 4,
                "waitNum": 0,
            },
            "securitySetting": {
                "category": "securitySetting",
                "fail": {
                    "danger": 0,
                    "info": 0,
                    "outOfDate": 0,
                    "risk": 0,
                    "warning": 0,
                },
                "failSeverity": "safe",
                "progress": 100,
                "runningItem": "",
                "total": 0,
                "waitNum": 0,
            },
            "systemCheck": {
                "category": "systemCheck",
                "fail": {
                    "danger": 0,
                    "info": 0,
                    "outOfDate": 0,
                    "risk": 0,
                    "warning": 0,
                },
                "failSeverity": "safe",
                "progress": 100,
                "runningItem": "",
                "total": 6,
                "waitNum": 0,
            },
            "update": {
                "category": "update",
                "fail": {
                    "danger": 0,
                    "info": 0,
                    "outOfDate": 0,
                    "risk": 0,
                    "warning": 0,
                },
                "failSeverity": "safe",
                "progress": 100,
                "runningItem": "",
                "total": 4,
                "waitNum": 0,
            },
            "userInfo": {
                "category": "userInfo",
                "fail": {
                    "danger": 0,
                    "info": 0,
                    "outOfDate": 0,
                    "risk": 0,
                    "warning": 0,
                },
                "failSeverity": "safe",
                "progress": 100,
                "runningItem": "",
                "total": 6,
                "waitNum": 0,
            },
        },
        "lastScanTime": "1588298442",
        "startTime": "",
        "success": True,
        "sysProgress": 100,
        "sysStatus": "safe",
    },
    "success": True,
}

DSM_6_CORE_SECURITY_UPDATE_OUTOFDATE = {
    "data": {
        "items": {
            "malware": {
                "category": "malware",
                "fail": {
                    "danger": 0,
                    "info": 0,
                    "outOfDate": 0,
                    "risk": 0,
                    "warning": 0,
                },
                "failSeverity": "safe",
                "progress": 100,
                "runningItem": "",
                "total": 3,
                "waitNum": 0,
            },
            "network": {
                "category": "network",
                "fail": {
                    "danger": 0,
                    "info": 0,
                    "outOfDate": 0,
                    "risk": 0,
                    "warning": 0,
                },
                "failSeverity": "safe",
                "progress": 100,
                "runningItem": "",
                "total": 4,
                "waitNum": 0,
            },
            "securitySetting": {
                "category": "securitySetting",
                "fail": {
                    "danger": 0,
                    "info": 0,
                    "outOfDate": 0,
                    "risk": 0,
                    "warning": 0,
                },
                "failSeverity": "safe",
                "progress": 100,
                "runningItem": "",
                "total": 0,
                "waitNum": 0,
            },
            "systemCheck": {
                "category": "systemCheck",
                "fail": {
                    "danger": 0,
                    "info": 0,
                    "outOfDate": 0,
                    "risk": 0,
                    "warning": 0,
                },
                "failSeverity": "safe",
                "progress": 100,
                "runningItem": "",
                "total": 6,
                "waitNum": 0,
            },
            "update": {
                "category": "update",
                "fail": {
                    "danger": 0,
                    "info": 0,
                    "outOfDate": 1,
                    "risk": 0,
                    "warning": 0,
                },
                "failSeverity": "outOfDate",
                "progress": 100,
                "runningItem": "",
                "total": 4,
                "waitNum": 0,
            },
            "userInfo": {
                "category": "userInfo",
                "fail": {
                    "danger": 0,
                    "info": 0,
                    "outOfDate": 0,
                    "risk": 0,
                    "warning": 0,
                },
                "failSeverity": "safe",
                "progress": 100,
                "runningItem": "",
                "total": 6,
                "waitNum": 0,
            },
        },
        "lastScanTime": "1590717640",
        "startTime": "",
        "success": True,
        "sysProgress": 100,
        "sysStatus": "outOfDate",
    },
    "success": True,
}
