"""DSM 7 SYNO.DSM.Info data."""

DSM_7_DSM_INFORMATION_DS213_PLUS = {
    "data": {
        "codepage": "enu",
        "model": "DS213+",
        "ram": 512,
        "serial": "XXXXXXXXXXX",
        "temperature": 30,
        "temperature_warn": False,
        "time": "Thu Apr 30 14:57:35 2020",
        "uptime": 3258607,
        "version": "24922",
        "version_string": "DSM 7.0-41222",
    },
    "success": True,
}

DSM_7_DSM_INFORMATION_DS918_PLUS = {
    "data": {
        "codepage": "fre",
        "model": "DS918+",
        "ram": 4096,
        "serial": "1920PDN001501",
        "temperature": 40,
        "temperature_warn": False,
        "time": "Sun Mar 29 19:33:41 2020",
        "uptime": 155084,
        "version": "24922",
        "version_string": "DSM 7.0-41222",
    },
    "success": True,
}

DSM_7_DSM_INFORMATION = DSM_7_DSM_INFORMATION_DS918_PLUS
