"""DSM 5 SYNO.DSM.Info data."""

DSM_5_DSM_INFORMATION_DS410J = {
    "data": {
        "codepage": "enu",
        "model": "DS410j",
        "ram": 128,
        "serial": "A3G7N00628",
        "temperature": 52,
        "temperature_warn": False,
        "time": "Mon Apr 13 18:26:27 2020",
        "uptime": 7077254,
        "version": "5967",
        "version_string": "DSM 5.2-5967 Update 9",
    },
    "success": True,
}

DSM_5_DSM_INFORMATION_DS3615XS = {
    "data": {
        "codepage": "rus",
        "model": "DS3615xs",
        "ram": 6144,
        "serial": "B3J4N01003",
        "temperature": 40,
        "time": "Sat Apr 25 20:21:57 2020",
        "uptime": 3897,
        "version": "5967",
        "version_string": "DSM 5.2-5967 Update 9",
    },
    "success": True,
}

DSM_5_DSM_INFORMATION = DSM_5_DSM_INFORMATION_DS3615XS
