"""DSM 6 SYNO.DownloadStation.Task data."""

DSM_6_DOWNLOAD_STATION_TASK_LIST = {
    "data": {
        "offset": 0,
        "tasks": [
            {
                "additional": {
                    "detail": {
                        "completed_time": 0,
                        "connected_leechers": 0,
                        "connected_peers": 0,
                        "connected_seeders": 0,
                        "create_time": 1550089068,
                        "destination": "Folder/containing/downloads",
                        "seedelapsed": 0,
                        "started_time": 1592549339,
                        "total_peers": 0,
                        "total_pieces": 1239,
                        "unzip_password": "",
                        "uri": "magnet:?xt=urn:btih:1234ABCD1234ABCD1234ABCD1234ABCD1234ABCD&dn=1234",
                        "waiting_seconds": 0,
                    },
                    "file": [
                        {
                            "filename": "INFO.nfo",
                            "index": 0,
                            "priority": "low",
                            "size": 1335,
                            "size_downloaded": 0,
                            "wanted": True,
                        },
                        {
                            "filename": "My super movie 2 2022.mkv",
                            "index": 1,
                            "priority": "normal",
                            "size": 1591087515,
                            "size_downloaded": 0,
                            "wanted": True,
                        },
                        {
                            "filename": "My super movie 2 sample.mkv",
                            "index": 2,
                            "priority": "normal",
                            "size": 2754524,
                            "size_downloaded": 0,
                            "wanted": False,
                        },
                        {
                            "filename": "My super movie 2021.mkv",
                            "index": 3,
                            "priority": "normal",
                            "size": 1155085341,
                            "size_downloaded": 0,
                            "wanted": True,
                        },
                        {
                            "filename": "My super movie 2021 sample.mkv",
                            "index": 4,
                            "priority": "normal",
                            "size": 4359701,
                            "size_downloaded": 0,
                            "wanted": False,
                        },
                        {
                            "filename": "My super movie 3 2023.mkv",
                            "index": 5,
                            "priority": "normal",
                            "size": 1288819263,
                            "size_downloaded": 0,
                            "wanted": True,
                        },
                        {
                            "filename": "My super movie 3 sample.mkv",
                            "index": 6,
                            "priority": "normal",
                            "size": 3077684,
                            "size_downloaded": 0,
                            "wanted": False,
                        },
                        {
                            "filename": "My super movie 4 2031.mkv",
                            "index": 7,
                            "priority": "normal",
                            "size": 1149397942,
                            "size_downloaded": 0,
                            "wanted": True,
                        },
                        {
                            "filename": "My super movie 4 sample.mkv",
                            "index": 8,
                            "priority": "normal",
                            "size": 2023179,
                            "size_downloaded": 0,
                            "wanted": False,
                        },
                    ],
                },
                "id": "dbid_86",
                "size": 5196586484,
                "status": "downloading",
                "title": "My super movie Complete 2021-2031",
                "type": "bt",
                "username": "Test_useR",
            },
            {
                "additional": {
                    "detail": {
                        "completed_time": 0,
                        "connected_leechers": 0,
                        "connected_peers": 0,
                        "connected_seeders": 0,
                        "create_time": 1551214114,
                        "destination": "Folder/containing/downloads",
                        "seedelapsed": 0,
                        "started_time": 1592549348,
                        "total_peers": 0,
                        "total_pieces": 948,
                        "unzip_password": "",
                        "uri": "magnet:?xt=urn:btih:1234ABCD1234ABCD1234ABCD1234ABCD1234ABCD&dn=1234",
                        "waiting_seconds": 0,
                    },
                    "file": [
                        {
                            "filename": "Blade Swipper 1984.mkv",
                            "index": 0,
                            "priority": "normal",
                            "size": 1986298376,
                            "size_downloaded": 1602519560,
                            "wanted": True,
                        }
                    ],
                },
                "id": "dbid_164",
                "size": 1986298376,
                "status": "downloading",
                "title": "Blade Swipper 1984.mkv",
                "type": "bt",
                "username": "Test_useR",
            },
            {
                "additional": {
                    "detail": {
                        "completed_time": 0,
                        "connected_leechers": 0,
                        "connected_peers": 50,
                        "connected_seeders": 50,
                        "create_time": 1585435581,
                        "destination": "Folder/containing/downloads",
                        "seedelapsed": 0,
                        "started_time": 1592549349,
                        "total_peers": 0,
                        "total_pieces": 0,
                        "unzip_password": "",
                        "uri": "magnet:?xt=urn:btih:1234ABCD1234ABCD1234ABCD1234ABCD1234ABCD&dn=1234",
                        "waiting_seconds": 0,
                    },
                    "file": [],
                },
                "id": "dbid_486",
                "size": 0,
                "status": "downloading",
                "title": "The falling State",
                "type": "bt",
                "username": "Test_useR",
            },
            {
                "additional": {
                    "detail": {
                        "completed_time": 0,
                        "connected_leechers": 0,
                        "connected_peers": 1,
                        "connected_seeders": 1,
                        "create_time": 1591562665,
                        "destination": "Folder/containing/downloads",
                        "seedelapsed": 0,
                        "started_time": 1591563597,
                        "total_peers": 0,
                        "total_pieces": 1494,
                        "unzip_password": "",
                        "uri": "magnet:?xt=urn:btih:1234ABCD1234ABCD1234ABCD1234ABCD1234ABCD&dn=1234",
                        "waiting_seconds": 0,
                    }
                },
                "id": "dbid_518",
                "size": 391580448,
                "status": "paused",
                "title": "Welcome to the North.mkv",
                "type": "bt",
                "username": "Test_useR",
            },
            {
                "additional": {
                    "detail": {
                        "completed_time": 1591565351,
                        "connected_leechers": 0,
                        "connected_peers": 0,
                        "connected_seeders": 0,
                        "create_time": 1591563606,
                        "destination": "Folder/containing/downloads",
                        "seedelapsed": 172800,
                        "started_time": 1592601577,
                        "total_peers": 0,
                        "total_pieces": 5466,
                        "unzip_password": "",
                        "uri": "magnet:?xt=urn:btih:1234ABCD1234ABCD1234ABCD1234ABCD1234ABCD&dn=1234",
                        "waiting_seconds": 0,
                    }
                },
                "id": "dbid_522",
                "size": 5731285821,
                "status": "finished",
                "title": "Birds of Pokémon.mkv",
                "type": "bt",
                "username": "Test_useR",
            },
            {
                "additional": {
                    "detail": {
                        "completed_time": 1591566799,
                        "connected_leechers": 0,
                        "connected_peers": 0,
                        "connected_seeders": 0,
                        "create_time": 1591566523,
                        "destination": "Folder/containing/downloads",
                        "seedelapsed": 0,
                        "started_time": 1591566696,
                        "total_peers": 0,
                        "total_pieces": 0,
                        "unzip_password": "",
                        "uri": "https://1fichier.com/?1234ABCD1234ABCD1234&af=22123",
                        "waiting_seconds": 0,
                    }
                },
                "id": "dbid_531",
                "size": 2811892495,
                "status": "finished",
                "title": "1234ABCD1234ABCD1234",
                "type": "https",
                "username": "Test_useR",
            },
            {
                "additional": {
                    "detail": {
                        "completed_time": 0,
                        "connected_leechers": 0,
                        "connected_peers": 0,
                        "connected_seeders": 0,
                        "create_time": 1591566903,
                        "destination": "Folder/containing/downloads",
                        "seedelapsed": 0,
                        "started_time": 0,
                        "total_peers": 0,
                        "total_pieces": 0,
                        "unzip_password": "",
                        "uri": "https://1fichier.com/?123ABC123ABC123ABC12",
                        "waiting_seconds": 0,
                    }
                },
                "id": "dbid_533",
                "size": 0,
                "status": "error",
                "status_extra": {"error_detail": "unknown"},
                "title": "?123ABC123ABC123ABC12",
                "type": "https",
                "username": "Test_useR",
            },
            {
                "additional": {
                    "detail": {
                        "completed_time": 0,
                        "connected_leechers": 0,
                        "connected_peers": 0,
                        "connected_seeders": 0,
                        "create_time": 1592605687,
                        "destination": "Folder/containing/downloads",
                        "seedelapsed": 0,
                        "started_time": 1592605731,
                        "total_peers": 0,
                        "total_pieces": 0,
                        "unzip_password": "",
                        "uri": "https://1fichier.com/?123ABC123ABC123ABC12",
                        "waiting_seconds": 0,
                    }
                },
                "id": "dbid_549",
                "size": 0,
                "status": "error",
                "status_extra": {"error_detail": "broken_link"},
                "title": "123ABC123ABC123ABC12",
                "type": "https",
                "username": "Test_useR",
            },
        ],
        "total": 8,
    },
    "success": True,
}
