"""DSM 6 SYNO.DownloadStation.Info data."""

DSM_6_DOWNLOAD_STATION_INFO_INFO = {
    "data": {"is_manager": True, "version": 3543, "version_string": "3.8-3543"},
    "success": True,
}

DSM_6_DOWNLOAD_STATION_INFO_CONFIG = {
    "data": {
        "bt_max_download": 0,
        "bt_max_upload": 800,
        "default_destination": "downloads",
        "emule_default_destination": None,
        "emule_enabled": False,
        "emule_max_download": 0,
        "emule_max_upload": 20,
        "ftp_max_download": 0,
        "http_max_download": 0,
        "nzb_max_download": 0,
        "unzip_service_enabled": False,
    },
    "success": True,
}
