"""DSM 6 SYNO.Core.System data."""

DSM_6_CORE_SYSTEM_DS918_PLUS = {
    "data": {
        "cpu_clock_speed": 1500,
        "cpu_cores": "4",
        "cpu_family": "Celeron",
        "cpu_series": "J3455",
        "cpu_vendor": "INTEL",
        "enabled_ntp": True,
        "firmware_date": "2020/07/08",
        "firmware_ver": "DSM 6.2.3-25426 Update 2",
        "model": "DS918+",
        "ntp_server": "time.google.com",
        "ram_size": 4096,
        "sata_dev": [],
        "serial": "1920PDN001501",
        "support_esata": "yes",
        "sys_temp": 40,
        "sys_tempwarn": False,
        "systempwarn": False,
        "temperature_warning": False,
        "time": "2020-10-19 23:33:52",
        "time_zone": "Brussels",
        "time_zone_desc": "(GMT+01:00) Brussels, Copenhagen, Madrid, Paris",
        "up_time": "75:12:9",
        "usb_dev": [
            {
                "cls": "hub",
                "pid": "0612",
                "producer": "Genesys Logic, Inc.",
                "product": "Hub",
                "rev": "92.23",
                "vid": "05e3",
            },
            {
                "cls": "other",
                "pid": "1790",
                "producer": "ASIX Electronics Corp.",
                "product": "AX88179 Gigabit Ethernet",
                "rev": "1.00",
                "vid": "0b95",
            },
            {
                "cls": "hub",
                "pid": "0610",
                "producer": "Genesys Logic, Inc.",
                "product": "4-port hub",
                "rev": "92.23",
                "vid": "05e3",
            },
            {
                "cls": "other",
                "pid": "0200",
                "producer": "Sigma Designs, Inc.",
                "product": "Aeotec Z-Stick Gen5 (ZW090) - UZB",
                "rev": "0.00",
                "vid": "0658",
            },
            {
                "cls": "ups",
                "pid": "0002",
                "producer": "American Power Conversion",
                "product": "Uninterruptible Power Supply",
                "rev": "1.06",
                "vid": "051d",
            },
        ],
    },
    "success": True,
}

DSM_6_CORE_SYSTEM_DS218_PLAY = {
    "data": {
        "cpu_clock_speed": 1400,
        "cpu_cores": "4",
        "cpu_family": "RTD1296",
        "cpu_series": "SoC",
        "cpu_vendor": "Realtek",
        "enabled_ntp": True,
        "firmware_date": "2020/07/14",
        "firmware_ver": "DSM 6.2.3-25426 Update 2",
        "model": "DS218play",
        "ntp_server": "pool.ntp.org",
        "ram_size": 1024,
        "serial": "123456abcdefg",
        "support_esata": "no",
        "sys_temp": 40,
        "sys_tempwarn": False,
        "systempwarn": False,
        "temperature_warning": False,
        "time": "2020-10-16 20:26:58",
        "time_zone": "Amsterdam",
        "time_zone_desc": "(GMT+01:00) Amsterdam, Berlin, Rome, Stockholm, Vienna",
        "up_time": "289:31:54",
        "usb_dev": [
            {
                "cls": "disk",
                "pid": "2621",
                "producer": "Western Digital Technologies, Inc.",
                "product": "Elements 2621",
                "rev": "10.26",
                "vid": "1058",
            }
        ],
    },
    "success": True,
}
